<?php

namespace Modules\Parametros\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Method;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DependencyInjection\InstanceManager;
use Modules\Cotacao\Modules\Mercadum\Controllers\IntegracaoMercadumController;
use Exception;

class ParametrosMercadumController extends \Teknisa\GER\Controllers\TeknisaCrud {

    protected $crudService;
    protected $dataSourceManager;
  	protected $connection;
  	protected $integracaoMercadum;

    public function __construct($crudService,  $environment, $dataSourceManager, $connection,  IntegracaoMercadumController $integracaoMercadum) {
        $this->crudService        = $crudService;
        $this->environment        = $environment;
        $this->dataSourceManager  = $dataSourceManager;
        $this->connection         = $connection;
        $this->integracaoMercadum = $integracaoMercadum;
    }

    
    public function saveMercadum(DTO\Request\Row $request, DTO\Response $response)
  	{
  		try {
            $row = $request->getRow();
  			if($row['IDINTGPEDCOL'] == "S"){
  			    $pedidoCotacao = $this->verificaPedidoCotacao($row);
  			    if($pedidoCotacao[0]["IDINTGPEDCOL"] == "N") {
  			        $this->updateTabPEDCOLGERAL($row);
  			    }
  			}
  			$this->updateMercadum($row);
  			$response->addMessage(new Message("Operação realizada com sucesso."));
  		} catch (\Exception $e) {
  			$response->setError(new Error($e->getMessage(), 500));
  		}
  	}
	
    public function updateMercadum($row){
      $sql = "UPDATE PARAMMERCADUM  
              SET IDULTINTEGRAMERCADUM = :P_IDULTINTEGRAMERCADUM,
                  DSWEBSERVICE = :P_DSWEBSERVICE,
                  IDINTGPEDCOL = :P_IDINTGPEDCOL,
                  IDINTGAUTOFORN = :P_IDINTGAUTOFORN,
                  IDTIPOAUTOFORN = :P_IDTIPOAUTOFORN,
                  IDINTGCONTPAG = :P_IDINTGCONTPAG,
                  IDINTGNOTIFIC = :P_IDINTGNOTIFIC
                  
                WHERE NRORG    = :P_NRORG";
      $stmt = $this->connection->prepare($sql);
      $stmt->execute(
          array(

              'P_IDULTINTEGRAMERCADUM'  => $row['IDULTINTEGRAMERCADUM'],
              'P_DSWEBSERVICE'          => $row['DSWEBSERVICE'],
              'P_IDINTGPEDCOL'          => $row['IDINTGPEDCOL'],
              'P_IDINTGAUTOFORN'        => $row['IDINTGAUTOFORN'],
              'P_IDTIPOAUTOFORN'        => $row['IDTIPOAUTOFORN'],
              'P_IDINTGCONTPAG'         => $row['IDINTGCONTPAG'],
              'P_IDINTGNOTIFIC'         => $row['IDINTGNOTIFIC'],
              'P_NRORG'                 => $row['NRORG']
          )   
      );
    }
    
    public function gerarChaveAcesso(DTO\Request $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();
            
            $nrorg = $row['NRORG'];
            $chave = md5(uniqid("TEKNISA", true));
            
            $this->salvaChaveAcesso($nrorg, $chave);
            
            $response->addMessage(new Message($chave));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage()));
        }
    }
    
    public function salvaChaveAcesso($nrorg, $chaveAcesso)
    {
        $sql = "UPDATE PARAMMERCADUM
                   SET DSTOKENINTGECO = :CHAVE_ACESSO
                WHERE NRORG = :NRORG";
        
        $params = array(
            "NRORG" => $nrorg,
            "CHAVE_ACESSO" => $chaveAcesso
        );
         
        $query = $this->connection->prepare($sql);
        
        $query->execute($params);
    }
    
    public function createParametrosMercadum(DTO\Request $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();
            
            $nrorg = $this->environment->getNrorg();
            
            $webservice = $row['URL'];
            
            //Padrão a ser encontrado na string de url para separar a parte que precisamos, caso exista.
            $termo = '#';
            $pattern = '/' . $termo . '/'; 
            if (preg_match($pattern, $webservice)) {
              $webservice = explode('#', $webservice, 2);
              $webservice = $webservice[0];
            } 
            
            $chave = md5(uniqid("TEKNISA", true));
            
            $this->createParamsMercadum($nrorg, $chave, $webservice);
            
            $response->addMessage(new Message($chave));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage()));
        }
    }
    
    public function createParamsMercadum($nrorg, $chaveAcesso, $webservice)
    {
        $sql = "
                 INSERT INTO PARAMMERCADUM 
                 (NRORG, IDULTINTEGRAMERCADUM, DSWEBSERVICE,IDINTGPEDCOL,IDINTGAUTOFORN,IDTIPOAUTOFORN,IDINTGCONTPAG,IDINTGNOTIFIC, DSTOKENINTGECO) 
                 VALUES ( :NRORG,'N',:WEBSERVICE,'N', 'N','M','N','N', :CHAVE_ACESSO)

                 ";
        
        $params = array(
            "NRORG"         => $nrorg,
            "CHAVE_ACESSO"  => $chaveAcesso,
            "WEBSERVICE"    => $webservice
        );
         
        $query = $this->connection->prepare($sql);
        
        $query->execute($params);
    }
    
    public function integracaoMercadum (DTO\Request\Row $request, DTO\Response $response){
        try{
            $row = $request->getRow();
            $this->integracaoMercadum->integracaoMercadumSupplier($row);
        } catch (Exception $e) {
            $error = new DTO\Response\Error($e->getMessage(), $e->getCode());
		    $response->setError($error);
        }
    }
    
    public function updateTabPEDCOLGERAL($row){
      $sql = "UPDATE PEDCOLGERAL 
                SET IDINTEGRAMCD = 'S' 
                WHERE IDINTEGRAMCD = 'N' AND NRORG = :P_NRORG";
      $stmt = $this->connection->prepare($sql);
      $stmt->execute(
          array(
              'P_NRORG' => $row['NRORG']
          )   
      );
    }
    
    public function verificaPedidoCotacao($row){
        $query = "SELECT IDINTGPEDCOL FROM PARAMMERCADUM WHERE NRORG = :P_NRORG";
        $stmt = $this->connection->prepare($query);
        $stmt->execute(
          array(
              'P_NRORG'=> $row['NRORG']
          )   
      );
      return $stmt->fetchAll();
	}
    
}